pub enum Entry<'a, T: Send + 'static> {
Occupied(OccupiedEntry<'a, T>),
Vacant(VacantEntry<'a, T>),
}Expand description
Entry into actor-local storage with type-safe access.
This wraps the underlying type-erased entry and provides typed access through boxing and downcasting.
Variants
Occupied(OccupiedEntry<'a, T>)
Value exists for this key.
Vacant(VacantEntry<'a, T>)
No value for this key.
Implementations
Sourceimpl<'a, T: Send + 'static> Entry<'a, T>
impl<'a, T: Send + 'static> Entry<'a, T>
Sourcepub fn or_insert(self, default: T) -> OccupiedEntry<'a, T>
pub fn or_insert(self, default: T) -> OccupiedEntry<'a, T>
Ensures a value is in the entry by inserting the default if empty,
and returns an OccupiedEntry.
Sourcepub fn or_insert_with<F: FnOnce() -> T>(self, f: F) -> OccupiedEntry<'a, T>
pub fn or_insert_with<F: FnOnce() -> T>(self, f: F) -> OccupiedEntry<'a, T>
Ensures a value is in the entry by inserting the result of the default
function if empty, and returns an OccupiedEntry.
Sourcepub fn and_modify<F: FnOnce(&mut T)>(self, f: F) -> Self
pub fn and_modify<F: FnOnce(&mut T)>(self, f: F) -> Self
Provides in-place mutable access to an occupied entry before any potential inserts into the map.
Sourceimpl<'a, T: Send + Default + 'static> Entry<'a, T>
impl<'a, T: Send + Default + 'static> Entry<'a, T>
Sourcepub fn or_default(self) -> OccupiedEntry<'a, T>
pub fn or_default(self) -> OccupiedEntry<'a, T>
Ensures a value is in the entry by inserting the default value if empty,
and returns an OccupiedEntry.