pub struct ActorLocal<T: Send + 'static> { /* private fields */ }Expand description
Per-actor local storage slot.
Declare as a static and access from handler methods via the context:
ⓘ
use hyperactor::actor_local::Entry;
static MY_LOCAL: ActorLocal<MyType> = ActorLocal::new();
fn handle(&mut self, cx: &Context<Self>, msg: MyMessage) {
// Get an entry (holds the lock)
let mut entry = MY_LOCAL.entry(cx);
// Use fluent API
*MY_LOCAL.entry(cx).or_default().get_mut() += 1;
// Or pattern match
match MY_LOCAL.entry(cx) {
Entry::Occupied(mut o) => {
let value = o.get_mut();
// modify value...
}
Entry::Vacant(v) => {
v.insert(initial_value);
}
}
}Each ActorLocal has its own internal lock, so accessing multiple
ActorLocal statics simultaneously is safe and will not deadlock.
Implementations
Sourceimpl<T: Send + 'static> ActorLocal<T>
impl<T: Send + 'static> ActorLocal<T>